node_key

Function node_key 

pub fn node_key(
    import_path: &str,
    kind: PackageKind,
    tuple: &TargetTuple,
) -> String
Canonical node key for a package at a tuple. Std packages get a std/ prefix so they never collide with a module package that happens to share an import path.